@@ -33,7 +33,10 @@ tik_build_request <- function(
     next_req = iterate_with_offset(
       "page",
       resp_complete = is_complete,
-      resp_pages = function(resp) if (resp_body_json(resp)$data$page_info$total_page < 1) 1 else resp_body_json(resp)$data$page_info$total_page
+      resp_pages = function(resp) {
+        if (is.null(resp_body_json(resp)$data$page_info$total_page)) return(NULL)
+        if (resp_body_json(resp)$data$page_info$total_page < 1) return(1) else return(resp_body_json(resp)$data$page_info$total_page)
+      }
     ),
     max_reqs = Inf
   )
